@@ -115,7 +115,7 @@ class CLI(cl1.CLI):
 
 		# generate passphrase.
 		elif self.arguments.present('--generate-passphrase'):
-			self.stop(message=f"Generated passphrase: {Formats.String('').generate(length=length, capitalize=True, digits=True)}", json=syst3m.defaults.options.json)
+			self.stop(message=f"Generated passphrase: {String('').generate(length=length, capitalize=True, digits=True)}", json=syst3m.defaults.options.json)
 
 		# invalid.
 		else: self.invalid(json=syst3m.defaults.options.json)
