@@ -364,7 +364,7 @@ class Database(object):
 
 		# check sample.
 		if not Files.exists(f"{self.path}"):
-			return r3sponse.error(f"Encrypted database root [{self.path}] does not exist".)
+			return r3sponse.error(f"Encrypted database root [{self.path}] does not exist.")
 		if not Files.exists(f"{self.path}.passphrase"):
 			response = self.aes.encrypt(self.aes.rsa.passphrase)
 			if not response.success: return response
@@ -406,12 +406,14 @@ class Database(object):
 	def load(self, 
 		# the subpath of the content (! param number 1).
 		path=None, 
+		# specify default to create when non existant.
+		default=None,
 	):
 		if not self.activated: return r3sponse.error(f"Encrypted database {self.path} is not activated yet, call database.activate() first.")
 		response = r3sponse.check_parameters({
 			"path:str":path,})
 		if not response.success: return response
-		content = self.DataObject(path=f"{self.path}/{path}", aes=self.aes)
+		content = self.DataObject(path=f"{self.path}/{path}", default=default, aes=self.aes)
 		response = content.load()
 		if not response.success: return response
 		return r3sponse.success(f"Successfully loaded content {path}.", {
@@ -440,6 +442,7 @@ class Database(object):
 			aes=None,
 		):
 			self.path = f"{utils.__clean_url__(path, strip_first=False, strip_last=True, remove_double_slash=True)}"
+			self.fp = self.file_path = FilePath(self.path)
 			self.aes = aes
 			self.base = FilePath(path).base()
 			self.content = None
